@@ -2,7 +2,7 @@
 /*! @file apolloron.h
     @brief Header file of libapolloron.
     @author Tachibanamasashi, Apolloron Project.
-    @date 2011-05-20
+    @date 2012-01-29
  ******************************************************************************/
 
 #ifndef _APOLLORON_H_
@@ -22,7 +22,7 @@ class Keys;
 
 /*! @brief Version of libapolloron.
  */
-#define LIBAPOLLORON_VERSION "0.44.8"
+#define LIBAPOLLORON_VERSION "0.44.9"
 
 extern const char *BUILD_DATE;
 extern const char *BUILD_HOST;
@@ -269,6 +269,8 @@ public:
   // MIME encoding
   virtual String& encodeMIME(const char * src_charset = "UTF-8", const char * dest_charset = "UTF-8", long max_width = 72, const char * return_str = "\n", const char enctype = 'B') const;
   virtual String& decodeMIME(const char * src_charset = "AUTODETECT", const char * dest_charset = "UTF-8") const;
+  virtual String& decodeMIMEB() const;
+  virtual String& decodeMIMEQ() const;
   virtual String& encodeBASE64(long max_width = 72, const char * return_str = "\n", const char * prefix_str = (const char *)0, const char * suffix_str = (const char *)0) const;
   virtual String& decodeBASE64() const;
   virtual String& encodeQuotedPrintable(long max_width = 72, const char * return_str = "\n", const char * prefix_str = (const char *)0, const char * suffix_str = (const char *)0) const;
