@@ -11,6 +11,9 @@
   Copyright (C) 2002  K.Kosako (kosako@sofnec.co.jp)
 
 **********************************************************************/
+#if _SUN == 1
+#include <alloca.h>
+#endif
 #include "regint.h"
 
 namespace apolloron {
